==> 0.0.49.tar.gz: lib/ThemeComponent/ThemeColorComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:bui_component/Constants/AppColors.dart';
import 'package:bui_component/DashBoardComponent.dart';
import 'package:cyclop/cyclop.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';

// ignore: must_be_immutable
class ThemeColorComponent extends StatefulWidget {
  final Function() onMenuPressed;
  final Function() onBackPressed;
  Color backgroundColor;

  ThemeColorComponent({
    Key key,
    @required this.onMenuPressed,
    @required this.backgroundColor,
    @required this.onBackPressed,
  }) : super(key: key);

  @override
  ThemeColorComponentState createState() => ThemeColorComponentState();
}

class ThemeColorComponentState extends State<ThemeColorComponent> {
  Color appbarColor = Colors.blueGrey;

  Color backgroundColor;

  Set<Color> swatches = Colors.primaries.map((e) => Color(e.value)).toSet();

  @override
  void initState() {
    super.initState();
    backgroundColor = widget.backgroundColor;

    getStringValuesSF();
  }

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString('stringValue');

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        backgroundColor = Color(colorCodeInt);
        this.mounted;
      });

      return stringValue;
    } else {
      backgroundColor = widget.backgroundColor;
    }
  }

  @override
  Widget build(BuildContext context) {
    final textTheme = Theme.of(context).textTheme;

    final bodyTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    final appbarTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.black
            : Colors.white;

    return Scaffold(
      backgroundColor: AppColors.APP_COLOR_WHITE,
      body: SafeArea(
        child: Center(
          child: Column(
            children: <Widget>[
              Container(
                height: 60,
                color: backgroundColor != null
                    ? backgroundColor
                    : AppColors.APP_COLOR_PRIMARY,
                child: Row(
                  children: <Widget>[
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          getStringValuesSF();
                          //widget.onMenuPressed();
                          widget.onBackPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.arrow_back,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 130,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.notifications_active,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.settings,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                    SizedBox(
                      width: 10,
                    ),
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          //widget.onMenuPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.messenger_rounded,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    _primarColor(),
                    // _secondaryColor(),
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Expanded _primarColor() {
    final textTheme = Theme.of(context).textTheme;

    final bodyTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.white
            : Colors.black87;

    final appbarTextColor =
        ThemeData.estimateBrightnessForColor(appbarColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    return Expanded(
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Center(
            child: Text(
              "Primary",
              style: textTheme.headline6.copyWith(
                  color: AppColors.APP_COLOR_BLACK,
                  fontWeight: FontWeight.bold),
            ),
          ),
          Center(
            child: ColorButton(
              darkMode: false,
              key: Key('c1'),
              color: backgroundColor,
              swatches: swatches,
              onColorChanged: (value) {
                setState(() {
                  backgroundColor = value;

                  DashBoardComponentState.color = [
                    backgroundColor,
                    AppColors.appWhite
                  ];

                  print(
                      "Colors====" + DashBoardComponentState.color.toString());
                  setPrefs(value);
                  this.mounted;
                });
              },
              onSwatchesChanged: (newSwatches) {
                setState(() {
                  swatches = newSwatches;
                });
              },
            ),
          ),
        ],
      ),
    );
  }

  Expanded _secondaryColor() {
    final textTheme = Theme.of(context).textTheme;

    final bodyTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    final appbarTextColor =
        ThemeData.estimateBrightnessForColor(appbarColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    return Expanded(
      child: Row(
        mainAxisAlignment: MainAxisAlignment.spaceEvenly,
        children: [
          Center(
            child: Text(
              "Secondary",
              style: textTheme.headline6
                  .copyWith(color: Colors.black ?? bodyTextColor),
            ),
          ),
          Center(
            child: ColorButton(
              darkMode: false,
              key: Key('c1'),
              color: backgroundColor ?? widget.backgroundColor,
              swatches: swatches,
              /*onColorChanged: (value) => setState(
                    () => backgroundColor = value,
              ),*/
              onColorChanged: (value) {
                setState(() {
                  backgroundColor = value;

                  setPrefs(value);
                });
              },
              onSwatchesChanged: (newSwatches) =>
                  setState(() => swatches = newSwatches),
            ),
          ),
        ],
      ),
    );
  }

  void setPrefs(Color value) async {
    var parts = value.toString().split('(');
    var date = parts.sublist(1).join('(').trim();
    List<String> c = date.split("");
    c.removeLast();
    String colorCode = c.join();

    SharedPreferences prefs = await SharedPreferences.getInstance();
    prefs.setString('stringValue', colorCode.toString());
  }
}

==> 0.0.50.tar.gz: lib/ThemeComponent/ThemeColorComponent.dart <==
/*
    Refer License for Terms & Conditions
 */
import 'package:bui_component/Constants/AppColors.dart';
import 'package:bui_component/Constants/AppStrings.dart';
import 'package:bui_component/DashBoardComponent.dart';
import 'package:cyclop/cyclop.dart';
import 'package:flutter/material.dart';
import 'package:flutter/cupertino.dart';
import 'package:flutter/foundation.dart';
import 'package:shared_preferences/shared_preferences.dart';

// ignore: must_be_immutable
class ThemeColorComponent extends StatefulWidget {
  final Function() onMenuPressed;
  final Function() onBackPressed;
  Color backgroundColor;
  Color secondaryColor;

  ThemeColorComponent({
    Key key,
    @required this.onMenuPressed,
    @required this.backgroundColor,
    @required this.onBackPressed,
    @required this.secondaryColor,
  }) : super(key: key);

  @override
  ThemeColorComponentState createState() => ThemeColorComponentState();
}

class ThemeColorComponentState extends State<ThemeColorComponent> {
  Color appbarColor = Colors.blueGrey;

  Color backgroundColor;
  Color secondaryBackgroundColor;

  Set<Color> swatches = Colors.primaries.map((e) => Color(e.value)).toSet();

  @override
  void initState() {
    super.initState();
    backgroundColor = widget.backgroundColor;
    secondaryBackgroundColor = widget.secondaryColor;

    getStringValuesSF();
  }

  getStringValuesSF() async {
    SharedPreferences prefs = await SharedPreferences.getInstance();
    //Return int
    String stringValue = prefs.getString(AppStrings.PRIMARY_THEME_COLOR);
    String secondaryColor = prefs.getString(AppStrings.SECONDARY_THEME_COLOR);

    if (stringValue != null) {
      int colorCodeInt = int.parse(stringValue);
      setState(() {
        backgroundColor = Color(colorCodeInt);
        this.mounted;
      });

      return stringValue;
    } else {
      backgroundColor = widget.backgroundColor;
    }
    if (secondaryColor != null) {
      int colorCodeInt = int.parse(secondaryColor);
      setState(() {
        secondaryBackgroundColor = Color(colorCodeInt);
        this.mounted;
      });

      return stringValue;
    } else {
      secondaryBackgroundColor = widget.secondaryColor;
    }
  }

  @override
  Widget build(BuildContext context) {
    final textTheme = Theme.of(context).textTheme;

    final bodyTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    final appbarTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.black
            : Colors.white;

    return Scaffold(
      backgroundColor: AppColors.APP_COLOR_WHITE,
      body: SafeArea(
        child: Center(
          child: Column(
            children: <Widget>[
              Container(
                height: 60,
                color: backgroundColor != null
                    ? backgroundColor
                    : AppColors.APP_COLOR_PRIMARY,
                child: Row(
                  children: <Widget>[
                    ClipRRect(
                      borderRadius: BorderRadius.all(Radius.circular(32.0)),
                      child: InkWell(
                        splashColor: AppColors.errorWarning,
                        focusColor: AppColors.APP_COLOR_WHITE,
                        onTap: () {
                          getStringValuesSF();
                          //widget.onMenuPressed();
                          widget.onBackPressed();
                        },
                        child: Padding(
                          padding: const EdgeInsets.all(12.0),
                          child: Icon(
                            Icons.arrow_back,
                            color: Colors.white,
                          ),
                        ),
                      ),
                    ),
                  ],
                ),
              ),
              Expanded(
                child: Column(
                  mainAxisAlignment: MainAxisAlignment.center,
                  children: <Widget>[
                    _primarColor,
                    SizedBox(
                      height: 20,
                    ),
                    _secondaryColor,
                  ],
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }

  Widget get _primarColor {
    final textTheme = Theme.of(context).textTheme;

    final bodyTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.white
            : Colors.black87;

    final appbarTextColor =
        ThemeData.estimateBrightnessForColor(appbarColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: [
        Center(
          child: Text(
            "Primary",
            style: textTheme.headline6.copyWith(
                color: AppColors.APP_COLOR_BLACK, fontWeight: FontWeight.bold),
          ),
        ),
        Container(
          child: ColorButton(
            darkMode: false,
            key: Key('c1'),
            color: backgroundColor,
            swatches: swatches,
            onColorChanged: (value) {
              setState(() {
                backgroundColor = value;

                DashBoardComponentState.color = [
                  backgroundColor,
                  AppColors.appWhite
                ];

                print("Colors====" + DashBoardComponentState.color.toString());
                setPrefs(value);
                this.mounted;
              });
            },
            onSwatchesChanged: (newSwatches) {
              setState(() {
                swatches = newSwatches;
              });
            },
          ),
        ),
      ],
    );
  }

  Widget get _secondaryColor {
    final textTheme = Theme.of(context).textTheme;

    final bodyTextColor =
        ThemeData.estimateBrightnessForColor(backgroundColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    final appbarTextColor =
        ThemeData.estimateBrightnessForColor(appbarColor) == Brightness.dark
            ? Colors.white70
            : Colors.black87;

    return Row(
      mainAxisAlignment: MainAxisAlignment.spaceAround,
      children: [
        Container(
          padding: EdgeInsets.all(1),
          child: Text(
            "Secondary",
            style: textTheme.headline6
                .copyWith(color: Colors.black ?? bodyTextColor),
          ),
        ),
        Center(
          child: ColorButton(
            darkMode: false,
            key: Key('c1'),
            color: secondaryBackgroundColor ?? widget.secondaryColor,
            swatches: swatches,
            /*onColorChanged: (value) => setState(
                    () => backgroundColor = value,
              ),*/
            onColorChanged: (value) {
              setState(() {
                secondaryBackgroundColor = value;

                setSecondaryPrefs(value);
              });
            },
            onSwatchesChanged: (newSwatches) =>
                setState(() => swatches = newSwatches),
          ),
        ),
      ],
    );
  }

  void setPrefs(Color value) async {
    var parts = value.toString().split('(');
    var date = parts.sublist(1).join('(').trim();
    List<String> c = date.split("");
    c.removeLast();
    String colorCode = c.join();

    SharedPreferences prefs = await SharedPreferences.getInstance();
    prefs.setString(AppStrings.PRIMARY_THEME_COLOR, colorCode.toString());
  }

  void setSecondaryPrefs(Color value) async {
    var parts = value.toString().split('(');
    var date = parts.sublist(1).join('(').trim();
    List<String> c = date.split("");
    c.removeLast();
    String colorCode = c.join();

    SharedPreferences prefs = await SharedPreferences.getInstance();
    prefs.setString(AppStrings.SECONDARY_THEME_COLOR, colorCode.toString());
  }
}
